@@ -6,6 +6,7 @@ __author__ = 'Zitong Lu'
 
 import nibabel as nib
 import numpy as np
+import os
 
 def limtozero(x):
     if x < 1e-15:
@@ -149,4 +150,12 @@ def correct_by_threshold(img, threshold):
 
     print("finished correction")
 
-    return img
\ No newline at end of file
+    return img
+
+def get_bg_ch2():
+
+    return os.path.abspath('./template/ch2.nii.gz')
+
+def get_bg_ch2bet():
+
+    return os.path.abspath('./template/ch2bet.nii.gz')
\ No newline at end of file
